<?php
// This file is part of Moodle - https://moodle.org/
//
// Moodle is free software: you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation, either version 3 of the License, or
// (at your option) any later version.
//
// Moodle is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with Moodle.  If not, see <https://www.gnu.org/licenses/>.

/**
 * Strings for component 'access', language 'id', version '5.0'.
 *
 * @package     access
 * @category    string
 * @copyright   1999 Martin Dougiamas and contributors
 * @license     https://www.gnu.org/copyleft/gpl.html GNU GPL v3 or later
 */

defined('MOODLE_INTERNAL') || die();

$string['access'] = 'Aksesibilitas';
$string['accesshelp'] = 'Bantuan aksesibilitas';
$string['accesskey'] = 'Kunci akses, {$a}';
$string['accessstatement'] = 'Pernyataan aksesibilitas';
$string['activitynext'] = 'Aktivitas selanjutnya';
$string['activityprev'] = 'Aktivitas sebelumnya';
$string['breadcrumb'] = 'Bilah navigasi';
$string['eventcontextlocked'] = 'Konteks dibekukan';
$string['eventcontextunlocked'] = 'Konteks tidak dibekukan';
$string['hideblocka'] = 'Sembunyikan blok {$a}';
$string['showblocka'] = 'Tampilkan blok {$a}';
$string['sitemap'] = 'Peta situs';
$string['skipa'] = 'Abaikan {$a}';
$string['skipblock'] = 'Abaikan blok';
$string['skipnavigation'] = 'Abaikan navigasi';
$string['skipto'] = 'Lewati ke {$a}';
$string['tocontent'] = 'Lewati ke konten utama';
$string['tonavigation'] = 'Menuju navigasi';
$string['youarehere'] = 'Anda di sini';
